"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getInputOptions = void 0;
const tslib_1 = require("tslib");
const plugin_commonjs_1 = tslib_1.__importDefault(require("@rollup/plugin-commonjs"));
const plugin_json_1 = tslib_1.__importDefault(require("@rollup/plugin-json"));
const plugin_node_resolve_1 = tslib_1.__importDefault(require("@rollup/plugin-node-resolve"));
const plugin_typescript_1 = tslib_1.__importDefault(require("@rollup/plugin-typescript"));
const rollup_plugin_filesize_1 = tslib_1.__importDefault(require("rollup-plugin-filesize"));
const rollup_plugin_lit_css_1 = tslib_1.__importDefault(require("rollup-plugin-lit-css"));
const rollup_plugin_styles_1 = tslib_1.__importDefault(require("rollup-plugin-styles"));
const rollup_plugin_transform_tagged_template_1 = tslib_1.__importDefault(require("rollup-plugin-transform-tagged-template"));
const rollup_plugin_visualizer_1 = require("rollup-plugin-visualizer");
const transformers_1 = require("../transformers");
const parserOptions = {
    sourceType: 'module',
};
// https://rollupjs.org/configuration-options/
const getInputOptions = (globals, analyze, open) => ({
    context: 'this',
    input: 'src/index.ts',
    // modules which shouldn't be included in the bundle
    external: globals ? Object.keys(globals) : undefined,
    onwarn(warning, warn) {
        // The IIFE export doesn't have a namespace since component exports
        // are expected to be top-level objects
        if (warning.code === 'MISSING_NAME_OPTION_FOR_IIFE_EXPORT') {
            return;
        }
        const nodeModulesNamespaceConflict = warning.reexporter && warning.reexporter.indexOf('node_modules') !== -1;
        const nodeModulesCircularDependency = warning.importer && warning.importer.indexOf('node_modules') !== -1;
        if (nodeModulesNamespaceConflict || nodeModulesCircularDependency) {
            return;
        }
        warn(warning);
    },
    plugins: [
        (0, plugin_node_resolve_1.default)({
            browser: true,
        }),
        (0, plugin_commonjs_1.default)(),
        (0, plugin_typescript_1.default)({
            outputToFilesystem: false,
            sourceMap: false,
            tsconfig: 'tsconfig.json',
        }),
        (0, plugin_json_1.default)(),
        (0, rollup_plugin_styles_1.default)({ mode: 'emit' }),
        (0, rollup_plugin_lit_css_1.default)({ specifier: '@microsoft/fast-element' }),
        (0, rollup_plugin_transform_tagged_template_1.default)({
            tagsToProcess: ['css'],
            transformer: transformers_1.transformCSSFragment,
            parserOptions,
        }),
        (0, rollup_plugin_transform_tagged_template_1.default)({
            tagsToProcess: ['html'],
            transformer: transformers_1.transformHTMLFragment,
            parserOptions,
        }),
        (0, rollup_plugin_filesize_1.default)({
            showMinifiedSize: false,
            showBrotliSize: true,
        }),
        analyze &&
            (0, rollup_plugin_visualizer_1.visualizer)((outputOptions) => {
                return {
                    title: `Rollup Visualizer - ${outputOptions.file}`,
                    filename: outputOptions.file.replace('.js', '.stats.html'),
                    gzipSize: true,
                    brotliSize: true,
                    open,
                };
            }),
    ].filter(Boolean),
});
exports.getInputOptions = getInputOptions;
